==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Your_Account/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_YES","Igen");
define("_NO","Nem");
define("_OPTIONAL","(Feltteles)");
define("_REQUIRED","(Ktelez)");
define("_SAVECHANGES","Vltozsok mentse");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_ERRORINVEMAIL","HIBA: hibs az e-mail cm");
define("_ERROREMAILSPACES","HIBA: az e-mail cm nem tartalmazhat szkzket!");
define("_ERRORINVNICK","HIBA: ismeretlen azonost");
define("_NICK2LONG","Az azonost tl hossz. Nem lehet 25 betnl hosszabb");
define("_NAMERESERVED","HIBA: ez a nv mr foglalt");
define("_NICKNOSPACES","HIBA: az azonost nem tartalmazhat szkzket");
define("_NICKTAKEN","HIBA: ez a nv mr foglalt");
define("_EMAILREGISTERED","HIBA:  ez az e-mail cm mr regisztrlva van");
define("_UUSERNAME","Felhasznlnv");
define("_FINISH","Befejezs");
define("_YOUUSEDEMAIL","Te, vagy valaki ms az e-mail cmedet");
define("_TOREGISTER","hasznlta regisztrlsra oldalunkon:");
define("_FOLLOWINGMEM","A felhasznl adatai:");
define("_UNICKNAME","-Azonost:");
define("_UPASSWORD","-Jelsz:");
define("_USERPASS4","Jelszavad:");
define("_YOUAREREGISTERED","Regisztrls befejezve! Hamarosan megrkezik a jelszavad a megadott e-mail cmedre.");
define("_THISISYOURPAGE","Ez a kezdoldalad");
define("_AVATAR","Avatar");
define("_WEBSITE","Weboldalad cme");
define("_ICQ","ICQ szm (ha van)");
define("_AIM","AIM szm (ha van)");
define("_YIM","YIM szm (ha van)");
define("_MSNM","MSNM szm (ha van)");
define("_LOCATION","Lakhely");
define("_OCCUPATION","Foglalkozs");
define("_INTERESTS","rdekldsi krk");
define("_SIGNATURE","Alrs");
define("_MYHOMEPAGE","Honlapom:");
define("_MYEMAIL","e-mail cmem:");
define("_EXTRAINFO","Egyb adatok");
define("_NOINFOFOR","Nincs informci errl a felhasznlrl:");
define("_LAST10COMMENTS","Az utols 10 hozzszls a kvetkez felhasznltl:");
define("_LAST10SUBMISSIONS","Az utols 10 cikk a kvetkez felhasznltl:");
define("_LOGININCOR","Sikertelen belps! Prbld meg jra...");
define("_USERLOGIN","Belps");
define("_USERREGLOGIN","Tag regisztrlsa/Belps");
define("_REGNEWUSER","j tag regisztrlsa");
define("_LIST","Lista");
define("_NEWUSER","j tag");
define("_PASSWILLSEND","(A jelszavad az itt megadott e-mail cmre fogjuk elkldeni)");
define("_COOKIEWARNING","Megjegyzs: a szemlyes belltsokat cookie-k (stik) troljk.");
define("_ASREGUSER","Regisztrlt tagknt:");
define("_ASREG1","Sajt neved alatt rhatsz hozzszlsokat");
define("_ASREG2","Sajt neveddel kldhetsz hreket");
define("_ASREG3","Sajt szemlyes terleted lehet a kezdoldalon");
define("_ASREG4","Kivlaszthatod, hny hrt akarsz megjelenteni a kezdoldalon");
define("_ASREG5","Szerkesztheted a hozzszlsokat");
define("_ASREG6","Klnbz dizjnok kztt vlaszthatsz (megjegyzs: csak akkor mkdik, ha az oldal kszti tbb dizjnt is ksztettek)");
define("_ASREG7","s egyb tuti dolgok...");
define("_REGISTERNOW","Regisztrlj most! Ingyenes!");
define("_WEDONTGIVE","Szemlyes adataid senkinek sem szolgltatjuk ki.");
define("_ALLOWEMAILVIEW","Ms tagok lthatjk az e-mail cmem");
define("_OPTION","Belltsok");
define("_PASSWORDLOST","Elfelejtetted a jelszavad?");
define("_NOPROBLEM","Nem gond. Csak add meg az azonostd, s kattins a \"Jelsz elkldse\" gombra. Egy automatikus levelet kapsz egy megerst kddal, ekkor jra meg kell adnod a jelszavad s a kapott megerst kdot, s j jelszt kldnk neked.");
define("_CONFIRMATIONCODE","Megerst kd");
define("_SENDPASSWORD","Jelsz elkldse");
define("_YOUARELOGGEDOUT","Kilptl!");
define("_SORRYNOUSERINFO","Sajnlom, nem talltam megfelel felhasznli adatokat");
define("_USERACCOUNT","A kvetkez tag:");
define("_AT","az oldalunkon");
define("_HASTHISEMAIL","regisztrlskor ezt az e-mail cmet adta meg.");
define("_AWEBUSERFROM","Egy felhasznl a kvetkez IP cmrl:");
define("_HASREQUESTED","krte a jelszavad elkldst.");
define("_YOURNEWPASSWORD","Az j jelszavad:");
define("_YOUCANCHANGE","Belpskor megvltoztathatod itt:");
define("_IFYOUDIDNOTASK","Ha nem te krted ezt, ne aggdj. Ezt az zenetet csak te ltod, ms nem. Ha tveds trtnt, csak lpj be az j jelszavaddal.");
define("_UPDATEFAILED","Hiba lpett fel a felhasznl adatainak frisstsekor. Krem, lpjen kapcsolatba az adminisztrtorral.");
define("_PASSWORD4","Jelsz a kvetkez tag rszre:");
define("_MAILED","Elkldve.");
define("_CODEREQUESTED","megerst kdot krt jelsz megvltoztatshoz.");
define("_YOURCODEIS","A megerst kdod:");
define("_WITHTHISCODE","Ezzel a kddal kaphatsz j jelszt oldalunkon:");
define("_IFYOUDIDNOTASK2","Ha nem krted ezt, ne aggdj, csak trld ki ezt a levelet.");
define("_CODEFOR","Megerst kd a kvetkez tag rszre:");
define("_USERPASSWORD4","Jelsz a kvetkez tag rszre:");
define("_UREALNAME","Valdi neved");
define("_UREALEMAIL","Valdi e-mail cmed");
define("_EMAILNOTPUBLIC","(Ez az e-mail cm nem nyilvnos, erre kldjk el a jelszavad, ha elvesztend)");
define("_UFAKEMAIL","Hamis e-mail cm");
define("_EMAILPUBLIC","(Ez lesz a nyilvnos e-mail cmed. Brmit berhatsz, kretlen (reklm)levelek is elfordulhatnak)");
define("_YOURHOMEPAGE","Honlapod");
define("_YOURAVATAR","Avatar");
define("_YICQ","ICQ");
define("_YAIM","AIM");
define("_YYIM","YIM");
define("_YMSNM","MSNM");
define("_YLOCATION","Lakhelyed");
define("_YOCCUPATION","Foglalkozsod");
define("_YINTERESTS","rdekldsi krd");
define("_255CHARMAX","(Max. 255 karakter. HTML kdokat is rhatsz az alrsodba)");
define("_CANKNOWABOUT","(Max. 255 karakter. Mit akarsz elmondani magadrl a tbbi tagnak)");
define("_TYPENEWPASSWORD","(ktszer add meg az j jelszt annak megvltoztatshoz)");
define("_SOMETHINGWRONG","Na, valamit elcsesztnk... Te nem utlod az ilyet?");
define("_PASSDIFFERENT","A kt jelsz klnbzik, pedig egyformnak kellene lennik.");
define("_CHARLONG","karakter hossz legyen");
define("_AVAILABLEAVATARS","Elrhet avatarok listja");
define("_NEWSINHOME","Hny hr jelenjen meg a foldalon?");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Szemlyes men aktivlsa");
define("_CHECKTHISOPTION","(Ha bekapcsolod, a kvetkez szveg jelenik meg a foldalon)");
define("_YOUCANUSEHTML","(HTML kdokat, pl. linkeket is hasznlhatsz)");
define("_SELECTTHEME","Vlassz egy tmt");
define("_THEMETEXT1","Ez az opci megvltoztatja az egsz site kinzett.");
define("_THEMETEXT2","Ezek a vltoztatsok csak rd vonatkoznak.");
define("_THEMETEXT3","A felhasznlk klnbz tmkkal nzhetik az oldalakat.");
define("_DISPLAYMODE","Nzet");
define("_SORTORDER","Sorbarendezs");
define("_COMMENTSWILLIGNORED","Az ennl kevesebbre osztlyozott hozzszlsok nem lesznek figyelembe vve.");
define("_UNCUT","Szretlen");
define("_EVERYTHING","Majdnem minden");
define("_FILTERMOSTANON","A legtbb nvtelen hozzszls szrse");
define("_USCORE","Osztlyzatok");
define("_SCORENOTE","A nvtelen hozzszlsok 0, tagok hozzszlsai 1 pontot rnek. A modertorok hozzadhatnak s elvehetnek pontokat.");
define("_NOSCORES","Osztlyozs rejtse");
define("_HIDDESCORES","(Elrejti az osztlyozst: az mkdik, csak nem ltszik.)");
define("_MAXCOMMENT","Hozzszlsok maximlis hossza");
define("_TRUNCATES","(A hossz hozzszlsok vgt levgja, s egy Tovbb... linkkel helyettesti. Kikapcsolshoz llts be valami j nagy rtket.)");
define("_BYTESNOTE","byte (1024 bytes = 1K)");
define("_USENDPRIVATEMSG","Szemlyes zenet kldse a kvetkez tagnak:");
define("_THEMESELECTION","Tma kivlasztsa");
define("_COMMENTSCONFIG","Hozzszlsok belltsa");
define("_HOMECONFIG","Foldal belltsa");
define("_PERSONALINFO","Szemlyes adatok");
define("_USERSTATUS","Tag jelenlegi sttusa");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Adataid megvltoztatsa");
define("_CONFIGCOMMENTS","Hozzszlsok belltsa");
define("_CHANGEHOME","Foldal belltsa");
define("_LOGOUTEXIT","Kilps");
define("_SELECTTHETHEME","Tma kivlasztsa");
define("_PRIVATEMESSAGES","Szemlyes zeneteid");
define("_EDITUSER","Tag szerkesztse");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_YES","Igen");
define("_NO","Nem");
define("_OPTIONAL","(Feltteles)");
define("_REQUIRED","(Ktelez)");
define("_SAVECHANGES","Vltozsok mentse");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_ERRORINVEMAIL","HIBA: hibs az e-mail cm");
define("_ERROREMAILSPACES","HIBA: az e-mail cm nem tartalmazhat szkzket!");
define("_ERRORINVNICK","HIBA: ismeretlen azonost");
define("_NICK2LONG","Az azonost tl hossz. Nem lehet 25 betnl hosszabb");
define("_NAMERESERVED","HIBA: ez a nv mr foglalt");
define("_NICKNOSPACES","HIBA: az azonost nem tartalmazhat szkzket");
define("_NICKTAKEN","HIBA: ez a nv mr foglalt");
define("_EMAILREGISTERED","HIBA:  ez az e-mail cm mr regisztrlva van");
define("_UUSERNAME","Felhasznlnv");
define("_FINISH","Befejezs");
define("_YOUUSEDEMAIL","Te, vagy valaki ms az e-mail cmedet");
define("_TOREGISTER","hasznlta regisztrlsra oldalunkon:");
define("_FOLLOWINGMEM","A felhasznl adatai:");
define("_UNICKNAME","-Azonost:");
define("_UPASSWORD","-Jelsz:");
define("_USERPASS4","Jelszavad:");
define("_YOUAREREGISTERED","Regisztrls befejezve! Hamarosan megrkezik a jelszavad a megadott e-mail cmedre.");
define("_THISISYOURPAGE","Ez a kezdoldalad");
define("_AVATAR","Avatar");
define("_WEBSITE","Weboldalad cme");
define("_ICQ","ICQ szm (ha van)");
define("_AIM","AIM szm (ha van)");
define("_YIM","YIM szm (ha van)");
define("_MSNM","MSNM szm (ha van)");
define("_LOCATION","Lakhely");
define("_OCCUPATION","Foglalkozs");
define("_INTERESTS","rdekldsi krk");
define("_SIGNATURE","Alrs");
define("_MYHOMEPAGE","Honlapom:");
define("_MYEMAIL","e-mail cmem:");
define("_EXTRAINFO","Egyb adatok");
define("_NOINFOFOR","Nincs informci errl a felhasznlrl:");
define("_LAST10COMMENTS","Az utols 10 hozzszls a kvetkez felhasznltl:");
define("_LAST10SUBMISSIONS","Az utols 10 cikk a kvetkez felhasznltl:");
define("_LOGININCOR","Sikertelen belps! Prbld meg jra...");
define("_USERLOGIN","Belps");
define("_USERREGLOGIN","Tag regisztrlsa/Belps");
define("_REGNEWUSER","j tag regisztrlsa");
define("_LIST","Lista");
define("_NEWUSER","j tag");
define("_PASSWILLSEND","(A jelszavad az itt megadott e-mail cmre fogjuk elkldeni)");
define("_COOKIEWARNING","Megjegyzs: a szemlyes belltsokat cookie-k (stik) troljk.");
define("_ASREGUSER","Regisztrlt tagknt:");
define("_ASREG1","Sajt neved alatt rhatsz hozzszlsokat");
define("_ASREG2","Sajt neveddel kldhetsz hreket");
define("_ASREG3","Sajt szemlyes terleted lehet a kezdoldalon");
define("_ASREG4","Kivlaszthatod, hny hrt akarsz megjelenteni a kezdoldalon");
define("_ASREG5","Szerkesztheted a hozzszlsokat");
define("_ASREG6","Klnbz dizjnok kztt vlaszthatsz (megjegyzs: csak akkor mkdik, ha az oldal kszti tbb dizjnt is ksztettek)");
define("_ASREG7","s egyb tuti dolgok...");
define("_REGISTERNOW","Regisztrlj most! Ingyenes!");
define("_WEDONTGIVE","Szemlyes adataid senkinek sem szolgltatjuk ki.");
define("_ALLOWEMAILVIEW","Ms tagok lthatjk az e-mail cmem");
define("_OPTION","Belltsok");
define("_PASSWORDLOST","Elfelejtetted a jelszavad?");
define("_NOPROBLEM","Nem gond. Csak add meg az azonostd, s kattins a \"Jelsz elkldse\" gombra. Egy automatikus levelet kapsz egy megerst kddal, ekkor jra meg kell adnod a jelszavad s a kapott megerst kdot, s j jelszt kldnk neked.");
define("_CONFIRMATIONCODE","Megerst kd");
define("_SENDPASSWORD","Jelsz elkldse");
define("_YOUARELOGGEDOUT","Kilptl!");
define("_SORRYNOUSERINFO","Sajnlom, nem talltam megfelel felhasznli adatokat");
define("_USERACCOUNT","A kvetkez tag:");
define("_AT","az oldalunkon");
define("_HASTHISEMAIL","regisztrlskor ezt az e-mail cmet adta meg.");
define("_AWEBUSERFROM","Egy felhasznl a kvetkez IP cmrl:");
define("_HASREQUESTED","krte a jelszavad elkldst.");
define("_YOURNEWPASSWORD","Az j jelszavad:");
define("_YOUCANCHANGE","Belpskor megvltoztathatod itt:");
define("_IFYOUDIDNOTASK","Ha nem te krted ezt, ne aggdj. Ezt az zenetet csak te ltod, ms nem. Ha tveds trtnt, csak lpj be az j jelszavaddal.");
define("_UPDATEFAILED","Hiba lpett fel a felhasznl adatainak frisstsekor. Krem, lpjen kapcsolatba az adminisztrtorral.");
define("_PASSWORD4","Jelsz a kvetkez tag rszre:");
define("_MAILED","Elkldve.");
define("_CODEREQUESTED","megerst kdot krt jelsz megvltoztatshoz.");
define("_YOURCODEIS","A megerst kdod:");
define("_WITHTHISCODE","Ezzel a kddal kaphatsz j jelszt oldalunkon:");
define("_IFYOUDIDNOTASK2","Ha nem krted ezt, ne aggdj, csak trld ki ezt a levelet.");
define("_CODEFOR","Megerst kd a kvetkez tag rszre:");
define("_USERPASSWORD4","Jelsz a kvetkez tag rszre:");
define("_UREALNAME","Valdi neved");
define("_UREALEMAIL","Valdi e-mail cmed");
define("_EMAILNOTPUBLIC","(Ez az e-mail cm nem nyilvnos, erre kldjk el a jelszavad, ha elvesztend)");
define("_UFAKEMAIL","Hamis e-mail cm");
define("_EMAILPUBLIC","(Ez lesz a nyilvnos e-mail cmed. Brmit berhatsz, kretlen (reklm)levelek is elfordulhatnak)");
define("_YOURHOMEPAGE","Honlapod");
define("_YOURAVATAR","Avatar");
define("_YICQ","ICQ");
define("_YAIM","AIM");
define("_YYIM","YIM");
define("_YMSNM","MSNM");
define("_YLOCATION","Lakhelyed");
define("_YOCCUPATION","Foglalkozsod");
define("_YINTERESTS","rdekldsi krd");
define("_255CHARMAX","(Max. 255 karakter. HTML kdokat is rhatsz az alrsodba)");
define("_CANKNOWABOUT","(Max. 255 karakter. Mit akarsz elmondani magadrl a tbbi tagnak)");
define("_TYPENEWPASSWORD","(ktszer add meg az j jelszt annak megvltoztatshoz)");
define("_SOMETHINGWRONG","Na, valamit elcsesztnk... Te nem utlod az ilyet?");
define("_PASSDIFFERENT","A kt jelsz klnbzik, pedig egyformnak kellene lennik.");
define("_CHARLONG","karakter hossz legyen");
define("_AVAILABLEAVATARS","Elrhet avatarok listja");
define("_NEWSINHOME","Hny hr jelenjen meg a foldalon?");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Szemlyes men aktivlsa");
define("_CHECKTHISOPTION","(Ha bekapcsolod, a kvetkez szveg jelenik meg a foldalon)");
define("_YOUCANUSEHTML","(HTML kdokat, pl. linkeket is hasznlhatsz)");
define("_SELECTTHEME","Vlassz egy tmt");
define("_THEMETEXT1","Ez az opci megvltoztatja az egsz site kinzett.");
define("_THEMETEXT2","Ezek a vltoztatsok csak rd vonatkoznak.");
define("_THEMETEXT3","A felhasznlk klnbz tmkkal nzhetik az oldalakat.");
define("_DISPLAYMODE","Nzet");
define("_SORTORDER","Sorbarendezs");
define("_COMMENTSWILLIGNORED","Az ennl kevesebbre osztlyozott hozzszlsok nem lesznek figyelembe vve.");
define("_UNCUT","Szretlen");
define("_EVERYTHING","Majdnem minden");
define("_FILTERMOSTANON","A legtbb nvtelen hozzszls szrse");
define("_USCORE","Osztlyzatok");
define("_SCORENOTE","A nvtelen hozzszlsok 0, tagok hozzszlsai 1 pontot rnek. A modertorok hozzadhatnak s elvehetnek pontokat.");
define("_NOSCORES","Osztlyozs rejtse");
define("_HIDDESCORES","(Elrejti az osztlyozst: az mkdik, csak nem ltszik.)");
define("_MAXCOMMENT","Hozzszlsok maximlis hossza");
define("_TRUNCATES","(A hossz hozzszlsok vgt levgja, s egy Tovbb... linkkel helyettesti. Kikapcsolshoz llts be valami j nagy rtket.)");
define("_BYTESNOTE","byte (1024 bytes = 1K)");
define("_USENDPRIVATEMSG","Szemlyes zenet kldse a kvetkez tagnak:");
define("_THEMESELECTION","Tma kivlasztsa");
define("_COMMENTSCONFIG","Hozzszlsok belltsa");
define("_HOMECONFIG","Foldal belltsa");
define("_PERSONALINFO","Szemlyes adatok");
define("_USERSTATUS","Tag jelenlegi sttusa");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Adataid megvltoztatsa");
define("_CONFIGCOMMENTS","Hozzszlsok belltsa");
define("_CHANGEHOME","Foldal belltsa");
define("_LOGOUTEXIT","Kilps");
define("_SELECTTHETHEME","Tma kivlasztsa");
define("_PRIVATEMESSAGES","Szemlyes zeneteid");
define("_EDITUSER","Tag szerkesztse");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>
